@@ -1,18 +1,19 @@
 package File::ChangeNotify::Event;
-{
-  $File::ChangeNotify::Event::VERSION = '0.23';
-}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Moose;
-use Moose::Util::TypeConstraints;
+our $VERSION = '0.25';
+
+use Types::Standard qw( Str );
+use Type::Utils qw( enum );
+
+use Moo;
 
 has path => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -32,18 +33,25 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::ChangeNotify::Event - Class for file change events
 
 =head1 VERSION
 
-version 0.23
+version 0.25
 
 =head1 SYNOPSIS
 
-    for my $event ( $watcher->new_events() )
-    {
+    my $watcher = File::ChangeNotify->instantiate_watcher(
+        directories => [ '/my/path', '/my/other' ],
+        filter      => qr/\.(?:pm|conf|yml)$/,
+        exclude => [ 't', 'root', qr(/(?!\.)[^/]+$) ],
+    );
+
+    for my $event ( $watcher->new_events() ) {
         print $event->path(), ' - ', $event->type(), "\n";
     }
 
@@ -79,13 +87,20 @@ Returns the path of the changed file or directory.
 
 Returns the type of event.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=File-ChangeNotify>
+(or L<bug-file-changenotify@rt.cpan.org|mailto:bug-file-changenotify@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
